@@ -3,7 +3,7 @@ from __future__ import annotations
 import logging
 import re
 from itertools import groupby
-from typing import TYPE_CHECKING, Pattern, Any, List
+from typing import TYPE_CHECKING, Pattern, Any
 
 from checkov.common.bridgecrew.check_type import CheckType
 
@@ -25,13 +25,16 @@ class SuppressionsIntegration(BaseIntegrationFeature):
     def __init__(self, bc_integration: BcPlatformIntegration) -> None:
         super().__init__(bc_integration=bc_integration, order=2)  # must be after the custom policies integration
         self.suppressions: dict[str, list[dict[str, Any]]] = {}
-        self.suppressions_url = f"{self.bc_integration.api_url}/api/v1/suppressions"
 
         # bcorgname_provider_timestamp (ex: companyxyz_aws_1234567891011)
         # the provider may be lower or upper depending on where the policy was created
         self.custom_policy_id_regex = re.compile(r'^[a-zA-Z0-9]+_[a-zA-Z]+_\d{13}$')
         self.repo_name_regex: Pattern[str] | None = None
 
+    @property
+    def suppressions_url(self) -> str:
+        return f"{self.bc_integration.api_url}/api/v1/suppressions"
+
     def is_valid(self) -> bool:
         return (
             self.bc_integration.is_integration_configured()
@@ -213,12 +216,12 @@ class SuppressionsIntegration(BaseIntegrationFeature):
         # not used
         pass
 
-    def get_policy_level_suppressions(self) -> List[str]:
-        policy_level_suppressions = []
+    def get_policy_level_suppressions(self) -> dict[str, str]:
+        policy_level_suppressions = {}
         for check_suppressions in self.suppressions.values():
             for suppression in check_suppressions:
                 if suppression.get("suppressionType") == "Policy":
-                    policy_level_suppressions.append(suppression['policyId'])
+                    policy_level_suppressions[suppression['id']] = suppression['policyId']
                     break
         return policy_level_suppressions
 
