@@ -25,34 +25,25 @@ class TwistcliIntegration(ABC):
     def get_proxy_address(self) -> str:
         return f"{bc_integration.api_url}{self.vulnerabilities_base_path}/docker-images/twistcli/proxy"
 
-    def download_twistcli(self, cli_file_name: Path) -> None:
+    def download_twistcli(self, cli_file_name: Path) -> bool:
         # backwards compatibility, should be removed in a later stage
-        cli_file_name_path = cli_file_name if isinstance(cli_file_name, Path) else Path(cli_file_name)
+        try:
+            cli_file_name_path = cli_file_name if isinstance(cli_file_name, Path) else Path(cli_file_name)
+            os_type = platform.system().lower()
+            response = request_wrapper("GET",
+                                       f"{bc_integration.api_url}{self.vulnerabilities_base_path}/twistcli?os={os_type}",
+                                       headers=bc_integration.get_default_headers("GET"),
+                                       should_call_raise_for_status=True)
 
-        os_type = platform.system().lower()
-
-        response = request_wrapper("GET",
-                                   f"{bc_integration.api_url}{self.vulnerabilities_base_path}/twistcli?os={os_type}",
-                                   headers=bc_integration.get_default_headers("GET"),
-                                   should_call_raise_for_status=True)
-
-        cli_file_name_path.write_bytes(response.content)
-        cli_file_name_path.chmod(cli_file_name_path.stat().st_mode | stat.S_IEXEC)
-        logging.debug("twistcli downloaded and has execute permission")
-
-    # can be removed, if image scanning is also using report_results_asyncio
-    # make sure to remove it only after validating it isn't used from the platform
-    def report_results(self, twistcli_scan_result: Dict[str, Any], file_path: Path, **kwargs: Any) -> None:
-        payload = self.create_report(
-            twistcli_scan_result=twistcli_scan_result,
-            bc_platform_integration=bc_integration,
-            file_path=file_path,
-            **kwargs,
-        )
-
-        request_wrapper("POST", f"{bc_integration.api_url}{self.vulnerabilities_base_path}/results",
-                        headers=bc_integration.get_default_headers("POST"),
-                        json=payload, should_call_raise_for_status=True)
+            cli_file_name_path.write_bytes(response.content)
+            cli_file_name_path.chmod(cli_file_name_path.stat().st_mode | stat.S_IEXEC)
+            logging.debug("twistcli downloaded and has execute permission")
+            return True
+        except Exception:
+            logging.debug(
+                "Unexpected failure happened during downloading twistcli. details are below.\n"
+                "scanning is terminating. please try again. if it is repeated, please report.\n", exc_info=True)
+            return False
 
     async def report_results_async(
         self,
