@@ -12,18 +12,10 @@ https://pypi.org/project/stopit
 Public resources from ``stopit``
 """
 
-import pkg_resources
-
-from .utils import LOG, TimeoutException
+from .utils import TimeoutException
 from .threadstop import ThreadingTimeout, async_raise, threading_timeoutable
 from .signalstop import SignalTimeout, signal_timeoutable
 
-# PEP 396 style version marker
-try:
-    __version__ = pkg_resources.get_distribution(__name__).version
-except Exception:
-    LOG.warning("Could not get the package version from pkg_resources")
-    __version__ = 'unknown'
 
 __all__ = (
     'ThreadingTimeout', 'async_raise', 'threading_timeoutable',
