@@ -38,12 +38,13 @@ from checkov.common.bridgecrew.integration_features.features.custom_policies_int
 from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
 from checkov.common.bridgecrew.platform_integration import bc_integration
 from checkov.common.bridgecrew.integration_features.features.licensing_integration import integration as licensing_integration
+from checkov.common.bridgecrew.severities import BcSeverities
 from checkov.common.goget.github.get_git import GitGetter
 from checkov.common.output.baseline import Baseline
 from checkov.common.bridgecrew.check_type import checkov_runners
 from checkov.common.runners.runner_registry import RunnerRegistry
 from checkov.common.util import prompt
-from checkov.common.util.banner import banner as checkov_banner
+from checkov.common.util.banner import banner as checkov_banner, tool as checkov_tool
 from checkov.common.util.config_utils import get_default_config_paths
 from checkov.common.util.consts import CHECKOV_RUN_SCA_PACKAGE_SCAN_V2
 from checkov.common.util.docs_generator import print_checks
@@ -68,6 +69,7 @@ from checkov.secrets.runner import Runner as secrets_runner
 from checkov.serverless.runner import Runner as sls_runner
 from checkov.terraform.plan_runner import Runner as tf_plan_runner
 from checkov.terraform.runner import Runner as tf_graph_runner
+from checkov.terraform_json.runner import TerraformJsonRunner
 from checkov.version import version
 from checkov.yaml_doc.runner import Runner as yaml_runner
 from checkov.bicep.runner import Runner as bicep_runner
@@ -113,6 +115,7 @@ DEFAULT_RUNNERS = [
     circleci_pipelines_runner(),
     azure_pipelines_runner(),
     ansible_runner(),
+    TerraformJsonRunner(),
 ]
 
 
@@ -227,7 +230,7 @@ def run(banner: str = checkov_banner, argv: list[str] = sys.argv[1:]) -> int | N
         logger.debug('Using --list; setting source to DISABLED')
         source = SourceTypes[BCSourceType.DISABLED]
 
-    if CHECKOV_RUN_SCA_PACKAGE_SCAN_V2 and source.upload_results:
+    if CHECKOV_RUN_SCA_PACKAGE_SCAN_V2:
         DEFAULT_RUNNERS.append(sca_package_runner_2())
     else:
         DEFAULT_RUNNERS.append(sca_package_runner())
@@ -343,8 +346,8 @@ def run(banner: str = checkov_banner, argv: list[str] = sys.argv[1:]) -> int | N
     policy_level_suppression = suppressions_integration.get_policy_level_suppressions()
     bc_cloned_checks = custom_policies_integration.bc_cloned_checks
     runner_filter.bc_cloned_checks = bc_cloned_checks
-    custom_policies_integration.policy_level_suppression = policy_level_suppression
-    runner_filter.set_suppressed_policies(policy_level_suppression)
+    custom_policies_integration.policy_level_suppression = list(policy_level_suppression.keys())
+    runner_filter.set_suppressed_policies(list(policy_level_suppression.values()))
 
     if config.use_enforcement_rules:
         runner_filter.apply_enforcement_rules(repo_config_integration.code_category_configs)
@@ -576,7 +579,7 @@ class Checkov:
         # Parse mask into json with default dict. If self.config.mask is empty list, default dict will be assigned
         self._parse_mask_to_resource_attributes_to_omit()
 
-    def run(self, banner: str = checkov_banner) -> int | None:
+    def run(self, banner: str = checkov_banner, tool: str = checkov_tool) -> int | None:
         self.run_metadata = {
             "checkov_version": version,
             "python_executable": sys.executable,
@@ -628,6 +631,15 @@ class Checkov:
             # if a bc_api_key is passed it'll save it.  Otherwise it will check ~/.bridgecrew/credentials
             self.config.bc_api_key = bc_integration.persist_bc_api_key(self.config)
 
+            if not self.config.bc_api_key:
+                # check, if someone tries to use a severity filter without an API key
+                severities = {severity for severity in BcSeverities.__dict__.values() if isinstance(severity, str)}
+                if (
+                    (self.config.check and any(check in severities for check in self.config.check))
+                    or (self.config.skip_check and any(check in severities for check in self.config.skip_check))
+                ):
+                    logging.warning("Filtering checks by severity is only possible with an API key")
+
             excluded_paths = self.config.skip_path or []
 
             if self.config.var_file:
@@ -656,7 +668,7 @@ class Checkov:
                 resource_attr_to_omit=self.config.mask,
                 # TODO modify the output for git_history secret and remove the rewrite of enable_git_history_secret_scan
                 # enable_git_history_secret_scan=self.config.scan_secrets_history,
-                enable_git_history_secret_scan=False,
+                enable_git_history_secret_scan=False,  # expose after unite git history with secret scan
                 git_history_timeout=self.config.secrets_history_timeout
             )
 
@@ -673,7 +685,7 @@ class Checkov:
                 logger.debug('Using --list; setting source to DISABLED')
                 source = SourceTypes[BCSourceType.DISABLED]
 
-            if CHECKOV_RUN_SCA_PACKAGE_SCAN_V2 and source.upload_results:
+            if CHECKOV_RUN_SCA_PACKAGE_SCAN_V2:
                 self.runners.append(sca_package_runner_2())
             else:
                 self.runners.append(sca_package_runner())
@@ -683,7 +695,7 @@ class Checkov:
                 runner_registry.runner_filter = runner_filter
                 runner_registry.filter_runner_framework()
             else:
-                runner_registry = RunnerRegistry(banner, runner_filter, *self.runners)
+                runner_registry = RunnerRegistry(banner, runner_filter, *self.runners, tool=tool)
 
             runnerDependencyHandler = RunnerDependencyHandler(runner_registry)
             runnerDependencyHandler.validate_runner_deps()
@@ -787,7 +799,7 @@ class Checkov:
             policy_level_suppression = suppressions_integration.get_policy_level_suppressions()
             bc_cloned_checks = custom_policies_integration.bc_cloned_checks
             runner_filter.bc_cloned_checks = bc_cloned_checks
-            custom_policies_integration.policy_level_suppression = policy_level_suppression
+            custom_policies_integration.policy_level_suppression = list(policy_level_suppression.keys())
             runner_filter.run_image_referencer = licensing_integration.should_run_image_referencer()
             runner_filter.filtered_policy_ids = policy_metadata_integration.filtered_policy_ids
             logger.debug(f"Filtered list of policies: {runner_filter.filtered_policy_ids}")
@@ -796,8 +808,8 @@ class Checkov:
             policy_level_suppression = suppressions_integration.get_policy_level_suppressions()
             bc_cloned_checks = custom_policies_integration.bc_cloned_checks
             runner_filter.bc_cloned_checks = bc_cloned_checks
-            custom_policies_integration.policy_level_suppression = policy_level_suppression
-            runner_filter.set_suppressed_policies(policy_level_suppression)
+            custom_policies_integration.policy_level_suppression = list(policy_level_suppression.keys())
+            runner_filter.set_suppressed_policies(list(policy_level_suppression.values()))
 
             if self.config.use_enforcement_rules:
                 runner_filter.apply_enforcement_rules(repo_config_integration.code_category_configs)
@@ -836,7 +848,7 @@ class Checkov:
                         self.exit_run()
                     if baseline:
                         baseline.compare_and_reduce_reports(self.scan_reports)
-                    if bc_integration.is_integration_configured():
+                    if bc_integration.is_integration_configured() and bc_integration.bc_source and bc_integration.bc_source.upload_results:
                         self.upload_results(
                             root_folder=root_folder,
                             excluded_paths=runner_filter.excluded_paths,
