@@ -40,8 +40,8 @@ from checkov.common.util.secrets import omit_secret_value_from_line
 from checkov.runner_filter import RunnerFilter
 from checkov.secrets.consts import ValidationStatus, VerifySecretsResult
 from checkov.secrets.coordinator import EnrichedSecret, SecretsCoordinator
-from checkov.secrets.scan_git_history import scan_history, get_added_and_removed_commit_hash
 from checkov.secrets.plugins.load_detectors import get_runnable_plugins
+from checkov.secrets.scan_git_history import GitHistoryScanner
 
 if TYPE_CHECKING:
     from checkov.common.util.tqdm_utils import ProgressBar
@@ -154,8 +154,9 @@ class Runner(BaseRunner[None]):
             self._add_custom_detectors_to_metadata_integration()
             if root_folder:
                 if runner_filter.enable_git_history_secret_scan:
+                    git_history_scanner = GitHistoryScanner(root_folder, secrets, runner_filter.git_history_timeout)
                     settings.disable_filters(*['detect_secrets.filters.common.is_invalid_file'])
-                    scan_history(root_folder, secrets, runner_filter.git_history_timeout)
+                    git_history_scanner.scan_history(last_commit_scanned=runner_filter.git_history_last_commit_scanned)
                     logging.info(f'Secrets scanning git history for root folder {root_folder}')
                 else:
                     enable_secret_scan_all_files = runner_filter.enable_secret_scan_all_files
@@ -186,20 +187,23 @@ class Runner(BaseRunner[None]):
             secrets_duplication: dict[str, bool] = {}
 
             for key, secret in secrets:
-                added_commit_hash, removed_commit_hash = get_added_and_removed_commit_hash(
-                    key,
-                    runner_filter.enable_git_history_secret_scan,
-                    secret)
+                if runner_filter.enable_git_history_secret_scan:
+                    added_commit_hash, removed_commit_hash, code_line = \
+                        git_history_scanner.secret_store.get_added_and_removed_commit_hash(key, secret)
+                else:
+                    added_commit_hash, removed_commit_hash, code_line = None, None, None
                 check_id = getattr(secret, "check_id", SECRET_TYPE_TO_ID.get(secret.type))
                 if not check_id:
                     logging.debug(f'Secret was filtered - no check_id for line_number {secret.line_number}')
                     continue
                 secret_key = f'{key}_{secret.line_number}_{secret.secret_hash}'
                 if secret.secret_value and is_potential_uuid(secret.secret_value):
-                    logging.info(f"Removing secret due to UUID filtering: {hashlib.sha256(secret.secret_value.encode('utf-8')).hexdigest()}")
+                    logging.info(
+                        f"Removing secret due to UUID filtering: {hashlib.sha256(secret.secret_value.encode('utf-8')).hexdigest()}")
                     continue
                 if secret_key in secrets_duplication:
-                    logging.debug(f'Secret was filtered - secrets_duplication. line_number {secret.line_number}, check_id {check_id}')
+                    logging.debug(
+                        f'Secret was filtered - secrets_duplication. line_number {secret.line_number}, check_id {check_id}')
                     continue
                 else:
                     secrets_duplication[secret_key] = True
@@ -212,7 +216,10 @@ class Runner(BaseRunner[None]):
                     continue
                 result: _CheckResult = {'result': CheckResult.FAILED}
                 try:
-                    line_text = linecache.getline(secret.filename, secret.line_number)
+                    if runner_filter.enable_git_history_secret_scan and code_line is not None:
+                        line_text = code_line
+                    else:
+                        line_text = linecache.getline(secret.filename, secret.line_number)
                 except SyntaxError as e:
                     # If encoding is a problem, this is probably not human-readable source code
                     # hence there's no need in flagging this secret
@@ -395,14 +402,16 @@ class Runner(BaseRunner[None]):
 
         validation_status_by_check_id_and_resource = {}
         for validation_status_entity in verification_report:
-            if not all(required_key in validation_status_entity.keys() for required_key in ["violationId", "resourceId", "status"]):
+            if not all(required_key in validation_status_entity.keys() for required_key in
+                       ["violationId", "resourceId", "status"]):
                 logging.debug(f"{validation_status_entity} does not have all required keys, skipping")
                 continue
 
             key = f'{validation_status_entity["violationId"]}_{validation_status_entity["resourceId"]}'
             validation_status_by_check_id_and_resource[key] = validation_status_entity['status']
 
-        logging.debug(f'secrets verification api returned with {len(validation_status_by_check_id_and_resource.keys())} unique entries')
+        logging.debug(
+            f'secrets verification api returned with {len(validation_status_by_check_id_and_resource.keys())} unique entries')
 
         for secrets_record in report.failed_checks:
             if hasattr(secrets_record, "validation_status"):
