@@ -1,3 +1,4 @@
+import logging
 from abc import abstractmethod
 from collections.abc import Iterable
 from typing import List, Dict, Any
@@ -62,6 +63,9 @@ class BaseResourceValueCheck(BaseResourceCheck):
                 return CheckResult.UNKNOWN
             if value in expected_values:
                 return CheckResult.PASSED
+            if not isinstance(value, str) and str(value) in expected_values:
+                logging.debug(f"Check {self.id} is set to pass even though the type of value {value} is not str (it is {type(value)}), while {str(value)} is an expected value")
+                return CheckResult.PASSED
             if get_referenced_vertices_in_value(value=value, aliases={}, resources_types=[]):
                 # we don't provide resources_types as we want to stay provider agnostic
                 return CheckResult.UNKNOWN
