@@ -5,7 +5,7 @@ from checkov.common.models.enums import CheckCategories
 
 class BigQueryDatasetEncryptedWithCMK(BaseResourceValueCheck):
     def __init__(self):
-        name = "Ensure Big Query Tables are encrypted with Customer Supplied Encryption Keys (CSEK)"
+        name = "Ensure Big Query Datasets are encrypted with Customer Supplied Encryption Keys (CSEK)"
         id = "CKV_GCP_81"
         supported_resources = ['google_bigquery_dataset']
         categories = [CheckCategories.ENCRYPTION]
