@@ -23,7 +23,7 @@ class CloudArmorWAFACLCVE202144228(BaseResourceCheck):
                 f"rule/[{idx_rule}]/match/[0]/expr/[0]/expression",
             ]
             match = rule.get("match")
-            if match:
+            if match and isinstance(match, list):
                 expr = match[0].get("expr")
                 if expr and isinstance(expr[0], dict) and expr[0].get("expression") == ["evaluatePreconfiguredExpr('cve-canary')"]:
                     if rule.get("action") == ["allow"]:
