@@ -1,17 +1,20 @@
 from __future__ import annotations
 
 import logging
-from typing import Type, Any
+from typing import Type, Any, TYPE_CHECKING
 
-from checkov.common.graph.db_connectors.db_connector import DBConnector
-from checkov.common.graph.graph_manager import GraphManager
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR
 from checkov.terraform.graph_builder.local_graph import TerraformLocalGraph
 from checkov.terraform.parser import Parser
 
+from checkov.common.graph.graph_manager import GraphManager
+
+if TYPE_CHECKING:
+    from checkov.common.typing import LibraryGraphConnector
+
 
 class TerraformGraphManager(GraphManager[TerraformLocalGraph, "dict[str, dict[str, Any]]"]):
-    def __init__(self, db_connector: DBConnector, source: str = "") -> None:
+    def __init__(self, db_connector: LibraryGraphConnector, source: str = "") -> None:
         super().__init__(db_connector=db_connector, parser=Parser(), source=source)
 
     def build_graph_from_source_directory(
